@@ -82,10 +82,12 @@ xnee_ungrab_key (xnee_data* xd, int mode)
       xnee_verbose((xd, "data     %d\n", (int)xd->grab));
       xnee_verbose((xd, "stop key %d\n", xd->grab_keys->action_keys[mode].key));
       xnee_verbose((xd, "stop mod %d\n", AnyModifier));
+
       XUngrabKey (xd->grab,  
 		  xd->grab_keys->action_keys[mode].key,            
 		  AnyModifier,
 		  window);
+
       xd->grab_keys->grab=1;
       xd->grab_keys->action_keys[mode].key=0;
     }
@@ -278,6 +280,7 @@ xnee_grab_all_keys (xnee_data* xd)
       return XNEE_BAD_GRAB_DATA;
     }
 
+
   /* make sure we have a display to grab on*/
   if (xd->grab==NULL)
     {
@@ -303,6 +306,9 @@ xnee_grab_all_keys (xnee_data* xd)
 
       if (xd->grab_keys->action_keys[i].str != NULL )
 	{
+
+	  
+
  	  xnee_verbose((xd, "----      DEBUG STARTING\n" ));
  	  xnee_verbose((xd, "----      xnee_grab_all_keys %d \n",ak.key));
 
@@ -317,7 +323,8 @@ xnee_grab_all_keys (xnee_data* xd)
 	  if (ak.key!=0) 
 	    {
 	      xd->grab_keys->action_keys[i].key = ak.key;
-	      xnee_verbose((xd, "----  xnee_grab_all_keys %d\n",i));
+	      xnee_verbose((xd, "----  xnee_grab_all_keys on key=%d   (%dth one)\n",
+			    xd->grab_keys->action_keys[i].key, i));
 	      xd->grab_keys->grab=XNEE_GRAB_SET;
 	      
 	      XGrabKey (xd->grab,  
@@ -342,7 +349,7 @@ xnee_grab_all_keys (xnee_data* xd)
 
 
 
-static int
+int
 xnee_grab_keys_init(xnee_data *xd)
 {
   int i ;
@@ -378,103 +385,21 @@ static int     last_modifier_state     = 0 ;
   ( XNEE_OVERRIDE_TRUE == xnee_grab_handle_override(xd, XNEE_OVERRIDE_GET) )
 
 
-
-
-
-#ifdef USE_OBSOLETE
-static KeyCode mod_kcs[8];
-static int     mod_idx = 0 ;
-
-static int 
-xnee_mod_in_use_sub (xnee_km_tuple *km)
+void
+xnee_print_grabbed_keys(xnee_data *xd)
 {
   int i ;
-  int j ;
-  int found = 0;
-  int nr_of_found = 0;
-  int ret ;
 
-  for (i=0;i<km->kcs_idx;i++)
+  for (i=XNEE_GRAB_STOP;i<XNEE_GRAB_LAST;i++)
     {
-      for (j=0;j<mod_idx;j++)
-	{
-	  if ( 
-	      (km->kcs[i][0]==mod_kcs[j])
-	      ||
-	      (km->kcs[i][1]==mod_kcs[j])
-	      )
-	    {
-	      found = 1;
-	    }
-	}
-      if (found)
-	{
-	  found = 0;
-	  nr_of_found++;
-	}
+      fprintf(stderr, "  %d    %d  '%s'\n",
+	      i, 
+	      xd->grab_keys->action_keys[i].key,
+	      xd->grab_keys->action_keys[i].str)  ;
     }
-
-  /* No modiifiers pressed at all */
-  if ( mod_idx == 0 )
-    {
-      ret = XNEE_GRAB_NONE_PRESSED ;
-    }
-
-  /* Modifier pressed that is not grabbed by xnee  */
-  else if ( ( mod_idx > nr_of_found ) && (mod_idx>0) )
-    { 
-      ret = XNEE_GRAB_NONE_IN_USE ;
-    }
-
-  /* All modifier pressed that is grabbed by xnee  */
-  else if ( (nr_of_found==km->kcs_idx) && 
-	    ((km->kcs_idx)==mod_idx) && 
-	    (nr_of_found!=0) )
-    {
-      ret = XNEE_GRAB_ALL_IN_USE ;
-    }
-
-  /* Some modifier pressed that is grabbed by xnee  */
-  else if ( nr_of_found!=0 )
-    {
-      ret = XNEE_GRAB_SOME_IN_USE ;
-    }
-  else
-    {
-      ret = XNEE_GRAB_SOME_IN_USE ;
-    }
-
-/*   printf ("   SUB: %d %d %d : RETURN %d \n", nr_of_found, km->kcs_idx, mod_idx, ret);     */
-
-  return ret;
 }
 
 
-static void
-xnee_mod_in_use (xnee_grab_keys *xgk)
-{
-  last_modifier_state = current_modifier_state;
-
-  current_modifier_state = XNEE_GRAB_NONE_PRESSED ;
-
-  current_modifier_state = XNEE_MAX(current_modifier_state,
-			     xnee_mod_in_use_sub (&xgk->stop));
-
-  current_modifier_state = XNEE_MAX(current_modifier_state,
-			     xnee_mod_in_use_sub (&xgk->pause));
-
-  current_modifier_state = XNEE_MAX(current_modifier_state,
-			     xnee_mod_in_use_sub (&xgk->resume));
-
-  current_modifier_state = XNEE_MAX(current_modifier_state,
-			     xnee_mod_in_use_sub (&xgk->insert));
-
-  current_modifier_state = XNEE_MAX(current_modifier_state,
-			     xnee_mod_in_use_sub (&xgk->exec));
-  return ;
-}
-#endif 
-
 static int
 xnee_key_in_use (xnee_grab_keys *xgk, KeyCode kc)
 {
@@ -482,8 +407,8 @@ xnee_key_in_use (xnee_grab_keys *xgk, KeyCode kc)
 
   for (i=XNEE_GRAB_STOP;i<XNEE_GRAB_LAST;i++)
     {
-/*       printf (" compare: %d %d\n", */
-/* 	      xgk->action_keys[i].key, kc); */
+/*       fprintf (stderr, "\t --- compare: %d %d\n",  */
+/*  	      xgk->action_keys[i].key, kc);  */
       if (xgk->action_keys[i].key==kc)
 	{
 	  return 1;
@@ -589,7 +514,6 @@ xnee_handle_grab_key(xnee_data *xd, KeyCode kc, int mode)
 {
   int ret ;
 
-
   xnee_verbose((xd, "---> xnee_handle_grab_key %d %d   modifier_state=%d\n", kc, mode, current_modifier_state));
   current_modifier_state = XNEE_GRAB_ALL_IN_USE ;
 
@@ -668,10 +592,10 @@ xnee_save_or_print(xnee_data *xd, KeyCode kc, int mode)
 	ret = xnee_handle_grab_modifier(xd, kc, mode);
       }
 #endif
-    else
-      {
-	xnee_verbose((xd, "--- xnee_save_or_print treat an ordinary key\n")); 
-	ret = xnee_handle_grab_key(xd, kc, mode); 
+  else
+    {
+      xnee_verbose((xd, "--- xnee_save_or_print treat an ordinary key\n")); 
+      ret = xnee_handle_grab_key(xd, kc, mode); 
     }
 
 /*   if ( ret == XNEE_GRAB_DO_SAVE ) */
